aboutsummaryrefslogtreecommitdiff
path: root/backends/fs/ps2/ps2-fs-factory.h
diff options
context:
space:
mode:
Diffstat (limited to 'backends/fs/ps2/ps2-fs-factory.h')
-rw-r--r--backends/fs/ps2/ps2-fs-factory.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/backends/fs/ps2/ps2-fs-factory.h b/backends/fs/ps2/ps2-fs-factory.h
index a7a52fdca3..1b74ae25d1 100644
--- a/backends/fs/ps2/ps2-fs-factory.h
+++ b/backends/fs/ps2/ps2-fs-factory.h
@@ -26,14 +26,14 @@
#define PS2_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates PS2FilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class Ps2FilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<Ps2FilesystemFactory> {
+class Ps2FilesystemFactory : public FilesystemFactory, public Common::Singleton<Ps2FilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates PS2FilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/